@@ -1,11 +1,15 @@
-from typing import Any, Dict, Optional, Set, cast
+from typing import AbstractSet, Any, Dict, Mapping, Optional, cast
 
-from dagster import PipelineDefinition, PipelineRun, SolidDefinition, check
-from dagster.core.definitions.dependency import Node, NodeHandle
-from dagster.core.execution.context.compute import AbstractComputeExecutionContext
-from dagster.core.execution.context.system import PlanExecutionContext, StepExecutionContext
-from dagster.core.log_manager import DagsterLogManager
-from dagster.core.system_config.objects import ResolvedRunConfig
+from dagster import DagsterRun, JobDefinition, OpDefinition
+from dagster import _check as check
+from dagster._annotations import public
+from dagster._core.definitions.dependency import Node, NodeHandle
+from dagster._core.execution.context.compute import AbstractComputeExecutionContext
+from dagster._core.execution.context.system import PlanExecutionContext, StepExecutionContext
+from dagster._core.log_manager import DagsterLogManager
+from dagster._core.system_config.objects import ResolvedRunConfig
+from dagster._legacy import PipelineDefinition, PipelineRun, SolidDefinition
+from dagster._utils.backcompat import deprecation_warning
 
 
 class DagstermillExecutionContext(AbstractComputeExecutionContext):
@@ -18,7 +22,7 @@ class DagstermillExecutionContext(AbstractComputeExecutionContext):
         self,
         pipeline_context: PlanExecutionContext,
         pipeline_def: PipelineDefinition,
-        resource_keys_to_init: Set[str],
+        resource_keys_to_init: AbstractSet[str],
         solid_name: str,
         solid_handle: NodeHandle,
         solid_config: Any = None,
@@ -58,13 +62,15 @@ class DagstermillExecutionContext(AbstractComputeExecutionContext):
         check.str_param(key, "key")
         return self._pipeline_context.get_tag(key)
 
+    @public  # type: ignore
     @property
     def run_id(self) -> str:
         """str: The run_id for the context."""
         return self._pipeline_context.run_id
 
+    @public  # type: ignore
     @property
-    def run_config(self) -> Dict[str, Any]:
+    def run_config(self) -> Mapping[str, Any]:
         """dict: The run_config for the context."""
         return self._pipeline_context.run_config
 
@@ -73,14 +79,41 @@ class DagstermillExecutionContext(AbstractComputeExecutionContext):
         """:class:`dagster.ResolvedRunConfig`: The resolved_run_config for the context"""
         return self._pipeline_context.resolved_run_config
 
+    @public  # type: ignore
     @property
     def logging_tags(self) -> Dict[str, str]:
         """dict: The logging tags for the context."""
         return self._pipeline_context.logging_tags
 
+    @public  # type: ignore
+    @property
+    def job_name(self) -> str:
+        return self._pipeline_context.job_name
+
     @property
     def pipeline_name(self) -> str:
-        return self._pipeline_context.pipeline_name
+        deprecation_warning(
+            "DagstermillExecutionContext.pipeline_name",
+            "0.17.0",
+            "use the 'job_name' property instead.",
+        )
+        return self.job_name
+
+    @public  # type: ignore
+    @property
+    def job_def(self) -> JobDefinition:
+        """:class:`dagster.JobDefinition`: The job definition for the context.
+
+        This will be a dagstermill-specific shim.
+        """
+        return cast(
+            JobDefinition,
+            check.inst(
+                self._pipeline_def,
+                JobDefinition,
+                "Accessing job_def inside a legacy pipeline. Use pipeline_def instead.",
+            ),
+        )
 
     @property
     def pipeline_def(self) -> PipelineDefinition:
@@ -88,6 +121,11 @@ class DagstermillExecutionContext(AbstractComputeExecutionContext):
 
         This will be a dagstermill-specific shim.
         """
+        deprecation_warning(
+            "DagstermillExecutionContext.pipeline_def",
+            "0.17.0",
+            "use the 'job_def' property instead.",
+        )
         return self._pipeline_def
 
     @property
@@ -98,10 +136,20 @@ class DagstermillExecutionContext(AbstractComputeExecutionContext):
             required_resource_keys=self._resource_keys_to_init,
         )
 
+    @public  # type: ignore
+    @property
+    def run(self) -> DagsterRun:
+        """:class:`dagster.DagsterRun`: The job run for the context."""
+        return cast(DagsterRun, self._pipeline_context.pipeline_run)
+
     @property
     def pipeline_run(self) -> PipelineRun:
-        """:class:`dagster.PipelineRun`: The pipeline run for the context."""
-        return self._pipeline_context.pipeline_run
+        deprecation_warning(
+            "DagstermillExecutionContext.pipeline_run",
+            "0.17.0",
+            "use the 'run' property instead.",
+        )
+        return self.run
 
     @property
     def log(self) -> DagsterLogManager:
@@ -111,6 +159,16 @@ class DagstermillExecutionContext(AbstractComputeExecutionContext):
         """
         return self._pipeline_context.log
 
+    @public  # type: ignore
+    @property
+    def op_def(self) -> OpDefinition:
+        """:class:`dagster.OpDefinition`: The op definition for the context.
+
+        In interactive contexts, this may be a dagstermill-specific shim, depending whether an
+        op definition was passed to ``dagstermill.get_context``.
+        """
+        return cast(OpDefinition, self._pipeline_def.solid_def_named(self.solid_name))
+
     @property
     def solid_def(self) -> SolidDefinition:
         """:class:`dagster.SolidDefinition`: The solid definition for the context.
@@ -118,7 +176,12 @@ class DagstermillExecutionContext(AbstractComputeExecutionContext):
         In interactive contexts, this may be a dagstermill-specific shim, depending whether a
         solid definition was passed to ``dagstermill.get_context``.
         """
-        return cast(SolidDefinition, self.pipeline_def.solid_def_named(self.solid_name))
+        deprecation_warning(
+            "DagstermillExecutionContext.solid_def",
+            "0.17.0",
+            "use the 'op_def' property instead.",
+        )
+        return cast(SolidDefinition, self._pipeline_def.solid_def_named(self.solid_name))
 
     @property
     def solid(self) -> Node:
@@ -127,25 +190,42 @@ class DagstermillExecutionContext(AbstractComputeExecutionContext):
         In interactive contexts, this may be a dagstermill-specific shim, depending whether a
         solid definition was passed to ``dagstermill.get_context``.
         """
+        deprecation_warning(
+            "DagstermillExecutionContext.solid_def",
+            "0.17.0",
+            "use the 'op_def' property instead.",
+        )
         return self.pipeline_def.get_solid(self.solid_handle)
 
+    @public  # type: ignore
     @property
-    def solid_config(self) -> Any:
+    def op_config(self) -> Any:
         """collections.namedtuple: A dynamically-created type whose properties allow access to
-        solid-specific config."""
+        op-specific config."""
         if self._solid_config:
             return self._solid_config
 
         solid_config = self.resolved_run_config.solids.get(self.solid_name)
         return solid_config.config if solid_config else None
 
+    @property
+    def solid_config(self) -> Any:
+        """collections.namedtuple: A dynamically-created type whose properties allow access to
+        solid-specific config."""
+        deprecation_warning(
+            "DagstermillExecutionContext.solid_config",
+            "0.17.0",
+            "use the 'op_config' property instead.",
+        )
+        return self.op_config
+
 
 class DagstermillRuntimeExecutionContext(DagstermillExecutionContext):
     def __init__(
         self,
         pipeline_context: PlanExecutionContext,
         pipeline_def: PipelineDefinition,
-        resource_keys_to_init: Set[str],
+        resource_keys_to_init: AbstractSet[str],
         solid_name: str,
         step_context: StepExecutionContext,
         solid_handle: NodeHandle,
