@@ -17,6 +17,8 @@ class OutputNotebookIOManager(IOManager):
         self.asset_key_prefix = asset_key_prefix if asset_key_prefix else []
 
     def get_output_asset_key(self, context: OutputContext):
+        if context.has_asset_key:
+            return None
         return AssetKey([*self.asset_key_prefix, f"{context.step_key}_output_notebook"])
 
     def handle_output(self, context: OutputContext, obj: bytes):
@@ -37,7 +39,10 @@ class LocalOutputNotebookIOManager(OutputNotebookIOManager):
 
     def _get_path(self, context: OutputContext) -> str:
         """Automatically construct filepath."""
-        keys = context.get_run_scoped_output_identifier()
+        if context.has_asset_key:
+            keys = context.get_asset_identifier()
+        else:
+            keys = context.get_run_scoped_output_identifier()
         return str(Path(self.base_dir, *keys).with_suffix(".ipynb"))
 
     def handle_output(self, context: OutputContext, obj: bytes):
@@ -49,7 +54,7 @@ class LocalOutputNotebookIOManager(OutputNotebookIOManager):
         mkdir_p(os.path.dirname(output_notebook_path))
         with open(output_notebook_path, self.write_mode) as dest_file_obj:
             dest_file_obj.write(obj)
-        yield MetadataEntry("path", value=MetadataValue.path(output_notebook_path))
+        yield MetadataEntry("notebook", value=MetadataValue.notebook(output_notebook_path))
 
     def load_input(self, context) -> bytes:
         check.inst_param(context, "context", InputContext)
